==> elgg-3.0.5.zip: elgg-3.0.5/mod/invitefriends/languages/de.php <==
<?php
return array(

	'friends:invite' => 'Freunde einladen',
	
	'invitefriends:registration_disabled' => 'Die Registrierung von neuen Mitgliedern wurde auf dieser Community-Seite deaktiviert. Du kannst daher leider keine neuen Mitglieder einladen.',
	
	'invitefriends:introduction' => 'Um Deine Freunde einzuladen, dieser Community-Seite beizutreten, geben im Folgenden deren Email-Adressen ein (eine Email-Adresse pro Zeile):',
	'invitefriends:emails' => 'Email-Adressen (eine pro Zeile)',
	'invitefriends:message' => 'Nachricht',
	'invitefriends:subject' => 'Einladung für die Community-Webseite %s',

	'invitefriends:success' => 'Die Einladungen an Deine Freunde wurden versendet.',
	'invitefriends:invitations_sent' => 'Versendete Einladungen: %s. Es traten folgende Probleme auf:',
	'invitefriends:email_error' => 'Die folgenden Email-Adressen sind ungültig: %s',
	'invitefriends:already_members' => 'Die folgenden Leute sind bereits Mitglied der Community: %s',
	'invitefriends:noemails' => 'Es wurden keine Email-Adressen eingegeben.',
	
	'invitefriends:message:default' => 'Hallo,

Ich möchte Dich einladen, meiner Community-Seite %s beizutreten.',

	'invitefriends:email' => 'Du bist eingeladen, der Community-Seite %s beizutreten.

Die Einladung wurde von %s versendet. Folgende Nachricht wurde der Einladung beigefügt:

%s

Um der Community-Seite beizutreten, folge dem Link:

%s

Nachdem Du einen Account auf der Community-Seite erstellt hast, wird das Mitglied, das Dich eingeladen hat, automatisch in Deine Freundesliste aufgenommen.',
	
);

==> elgg-3.3.20.zip: elgg-3.3.20/mod/invitefriends/languages/de.php <==
<?php
/**
 * Translation file
 *
 * Note: don't change the return array to short notation because Transifex can't handle those during `tx push -s`
 */

return array(

	'friends:invite' => 'Freunde einladen',
	
	'invitefriends:registration_disabled' => 'Die Registrierung von neuen Mitgliedern wurde auf dieser Community-Seite deaktiviert. Du kannst daher leider keine neuen Mitglieder einladen.',
	
	'invitefriends:introduction' => 'Um Deine Freunde einzuladen, dieser Community-Seite beizutreten, geben im Folgenden deren Email-Adressen ein (eine Email-Adresse pro Zeile):',
	'invitefriends:emails' => 'Email-Adressen (eine pro Zeile)',
	'invitefriends:message' => 'Nachricht',
	'invitefriends:subject' => 'Einladung für die Community-Webseite %s',

	'invitefriends:success' => 'Die Einladungen an Deine Freunde wurden versendet.',
	'invitefriends:invitations_sent' => 'Versendete Einladungen: %s. Es traten folgende Probleme auf:',
	'invitefriends:email_error' => 'Die folgenden Email-Adressen sind ungültig: %s',
	'invitefriends:already_members' => 'Die folgenden Leute sind bereits Mitglied der Community: %s',
	'invitefriends:noemails' => 'Es wurden keine Email-Adressen eingegeben.',
	
	'invitefriends:message:default' => 'Hallo,

Ich möchte Dich einladen, meiner Community-Seite %s beizutreten.',

	'invitefriends:email' => 'Du bist eingeladen, der Community-Seite %s beizutreten.

Die Einladung wurde von %s versendet. Folgende Nachricht wurde der Einladung beigefügt:

%s

Um der Community-Seite beizutreten, folge dem Link:

%s

Nachdem Du einen Account auf der Community-Seite erstellt hast, wird das Mitglied, das Dich eingeladen hat, automatisch in Deine Freundesliste aufgenommen.',
	
);
